exxen library

Classes

LayoutSnapper
Serializes a given Element into a JSON-compatible map.
LayoutSnapperButton
A button widget that triggers a layout snapshot when pressed.

Extensions

ContextExxension on BuildContext
This file is part of the Exxention package, which provides a set of utility extensions for Dart and Flutter. This extension adds convenience methods to the BuildContext class.
StringPathExxension on String
This file is part of the Exxention package, which provides a set of utility extensions for Dart and Flutter.
WidgetExxension on Widget
A set of extension methods for the Widget class in Flutter.