transform method

Widget transform(
  1. Matrix4? transform
)

Add a transform widget around the widget with an optional transform value. If transform is null or invalid, it defaults to an identity matrix.

Implementation

Widget transform(Matrix4? transform) => Transform(
      transform: transform ?? Matrix4.identity(),
      child: this,
    );